C LAST UPDATE:
C++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C*************************
C**     KSM_SYSAHK      **
C*************************
C
CD-Routine: Get Systematic Absence Based on H, K - KSM_SYSAHK
C This is a variant on KSM_SYSABS and checks to see if a given 'h', 'k'
C reflection is absence regardless of 'l'. It only uses the lattice type
C and not the full symmetry.
CD-end
CD-Fortran:
        SUBROUTINE KSM_SYSAHK (IH,IK,ABSNT)
CD-end
      INCLUDE 'implicit_none.finc'
C
C Purpose: Variant of KSM_SYSABS checks to see if a given h,k is absent whatever
C          the l value (using only lattice type)
C
C Author:  Based on code from GENLAUE by Clifton et al.
C
C Arguments:
C
      INTEGER IH
      INTEGER IK
      LOGICAL ABSNT

CD-Parameters:
C IH       i (R)     h index 
C IK       i (R)     k index
C ABSNT    l (W)     returns =.TRUE. systematically absent, =.FALSE. not
CD-end
C
C====== GLOBALS:
C
      INCLUDE 'ksm_data.finc'
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
C====== Check for absence
C
      ABSNT = .FALSE.
      IF (ISYS.EQ.0) RETURN
      IF ((ISYS.EQ.2 .OR. ISYS.EQ.4) .AND. KSYS(3).EQ.0) THEN
         IF (MOD(IH+IK,2).NE.0) ABSNT = .TRUE.
      END IF
      RETURN
      END
